@@ -486,7 +486,7 @@
     <message>
         <location filename="../ProxyDialog.qml" line="51"/>
         <source>Port (e.g. 8080)</source>
-        <translation>Port (es. 8080)</translation>
+        <translation>Porta (es. 8080)</translation>
     </message>
 </context>
 <context>
@@ -568,7 +568,7 @@
     <message>
         <location filename="../SettingsDialog.qml" line="47"/>
         <source>Portuguese</source>
-        <translation type="unfinished"></translation>
+        <translation>Portoghese</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="48"/>
@@ -719,19 +719,19 @@
         <location filename="../SettingsDialog.qml" line="172"/>
         <location filename="../SettingsDialog.qml" line="360"/>
         <source>Category Feed One</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Categoria Uno</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="175"/>
         <location filename="../SettingsDialog.qml" line="369"/>
         <source>Category Feed Two</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed Categoria Due</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="178"/>
         <location filename="../SettingsDialog.qml" line="378"/>
         <source>Order Category Videos By</source>
-        <translation type="unfinished"></translation>
+        <translation>Ordina Categoria Video Per</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="181"/>
@@ -826,22 +826,22 @@
     <message>
         <location filename="../SettingsDialog.qml" line="350"/>
         <source>YouTube categories</source>
-        <translation type="unfinished"></translation>
+        <translation>Categorie YouTube</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="358"/>
         <source>Category feed one</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed categoria uno</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="367"/>
         <source>Category feed two</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed categoria due</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="376"/>
         <source>Order category videos by</source>
-        <translation type="unfinished"></translation>
+        <translation>Ordina categoria video per</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="468"/>
@@ -1004,7 +1004,7 @@
     <message>
         <location filename="../UploadDialog.qml" line="72"/>
         <source>Film &amp; Animation</source>
-        <translation type="unfinished"></translation>
+        <translation>Film &amp; Animazione</translation>
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="73"/>
@@ -1499,7 +1499,7 @@
     <message>
         <location filename="../main.qml" line="160"/>
         <source>Video(s) already in download queue</source>
-        <translation type="unfinished"></translation>
+        <translation>Video già presente(i) nella coda download</translation>
     </message>
     <message>
         <location filename="../main.qml" line="171"/>
@@ -1509,7 +1509,7 @@
     <message>
         <location filename="../main.qml" line="174"/>
         <source>Audio track(s) already in download queue</source>
-        <translation type="unfinished"></translation>
+        <translation>Traccia(e) audio già presente(i) nella coda download</translation>
     </message>
     <message>
         <source>Video added to favourites</source>
@@ -1537,97 +1537,97 @@
     <message>
         <location filename="../main.qml" line="33"/>
         <source>Cars &amp; Vehicles</source>
-        <translation type="unfinished">Auto &amp; Veicoli</translation>
+        <translation>Auto &amp; Veicoli</translation>
     </message>
     <message>
         <location filename="../main.qml" line="33"/>
         <source>Comedy</source>
-        <translation type="unfinished">Umorismo</translation>
+        <translation>Umorismo</translation>
     </message>
     <message>
         <location filename="../main.qml" line="34"/>
         <source>Education</source>
-        <translation type="unfinished">Istruzione</translation>
+        <translation>Istruzione</translation>
     </message>
     <message>
         <location filename="../main.qml" line="34"/>
         <source>Entertainment</source>
-        <translation type="unfinished">Intrattenimento</translation>
+        <translation>Intrattenimento</translation>
     </message>
     <message>
         <location filename="../main.qml" line="35"/>
         <source>Film &amp; Animation</source>
-        <translation type="unfinished"></translation>
+        <translation>Film &amp; Animazione</translation>
     </message>
     <message>
         <location filename="../main.qml" line="35"/>
         <source>Gaming</source>
-        <translation type="unfinished">Giochi</translation>
+        <translation>Giochi</translation>
     </message>
     <message>
         <location filename="../main.qml" line="36"/>
         <source>Howto &amp; Style</source>
-        <translation type="unfinished">Fai da te &amp; Stile</translation>
+        <translation>Fai da te &amp; Stile</translation>
     </message>
     <message>
         <location filename="../main.qml" line="36"/>
         <source>Music</source>
-        <translation type="unfinished">Musica</translation>
+        <translation>Musica</translation>
     </message>
     <message>
         <location filename="../main.qml" line="36"/>
         <source>News &amp; Politics</source>
-        <translation type="unfinished">Notizie &amp; Politica</translation>
+        <translation>Notizie &amp; Politica</translation>
     </message>
     <message>
         <location filename="../main.qml" line="37"/>
         <source>Non-profits &amp; Activism</source>
-        <translation type="unfinished">Non profit &amp; Attivismo</translation>
+        <translation>Non profit &amp; Attivismo</translation>
     </message>
     <message>
         <location filename="../main.qml" line="37"/>
         <source>People &amp; Blogs</source>
-        <translation type="unfinished">Persone &amp; Blog</translation>
+        <translation>Persone &amp; Blog</translation>
     </message>
     <message>
         <location filename="../main.qml" line="38"/>
         <source>Pets &amp; Animals</source>
-        <translation type="unfinished">Animali</translation>
+        <translation>Animali</translation>
     </message>
     <message>
         <location filename="../main.qml" line="38"/>
         <source>Science &amp; Technology</source>
-        <translation type="unfinished">Scienze &amp; Tecnologie</translation>
+        <translation>Scienze &amp; Tecnologie</translation>
     </message>
     <message>
         <location filename="../main.qml" line="39"/>
         <source>Sport</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../main.qml" line="39"/>
         <source>Travel &amp; Events</source>
-        <translation type="unfinished">Viaggi &amp; Eventi</translation>
+        <translation>Viaggi &amp; Eventi</translation>
     </message>
     <message>
         <location filename="../main.qml" line="41"/>
         <source>Relevance</source>
-        <translation type="unfinished">Pertinenza</translation>
+        <translation>Pertinenza</translation>
     </message>
     <message>
         <location filename="../main.qml" line="41"/>
         <source>Date</source>
-        <translation type="unfinished">Data</translation>
+        <translation>Data</translation>
     </message>
     <message>
         <location filename="../main.qml" line="41"/>
         <source>Views</source>
-        <translation type="unfinished"></translation>
+        <translation>Visualizzazioni</translation>
     </message>
     <message>
         <location filename="../main.qml" line="41"/>
         <source>Rating</source>
-        <translation type="unfinished">Voto</translation>
+        <translation>Voto</translation>
     </message>
     <message>
         <location filename="../main.qml" line="205"/>
