@@ -11,6 +11,10 @@ function restoreSettings() {
     }
     Settings.initialize();
     cuteTubeTheme = Settings.getSetting("theme");
+    var catOne = Settings.getSetting("categoryFeedOne");
+    var catTwo = Settings.getSetting("categoryFeedTwo");
+    var catOrder = Settings.getSetting("categoryOrder");
+    setCategoryFeeds(catOne, catTwo, catOrder);
     Controller.setOrientation(Settings.getSetting("screenOrientation"));
     if (Controller.getInstalledMediaPlayers().length > 1) {
         Controller.setMediaPlayer(Settings.getSetting("mediaPlayer"));
@@ -273,28 +277,8 @@ function search(query, order) {
     }
 }
 
-
-function toggleMenu() {
-    /* Show/hide the menu of the current view */
-
-    if (windowView.currentIndex == 0) {
-        windowView.currentItem.toggleMenu();
-    }
-    else {
-        windowView.currentItem.item.toggleMenu();
-    }
-}
-
-function toggleControls(showOrHide) {
-    /* Show/hide the notification area and menu bar */
-
-    notificationArea.visible = showOrHide;
-    menuBar.visible = showOrHide;
-}
-
 function stopPlaying() {
     Controller.setOrientation(Settings.getSetting("screenOrientation"));
     toggleControls(true);
     goToPreviousView();
-
 }
