@@ -134,6 +134,9 @@ function setDefaultSettings() {
                     [ "downloadQuality", "hq" ],
                     [ "downloadStatus", "paused" ],
                     [ "downloadPath", "/home/user/MyDocs/.cutetube/" ],
+                    [ "categoryFeedOne", "MostRecent"],
+                    [ "categoryFeedTwo", "MostViewed"],
+                    [ "categoryOrder", "relevance"],
                     [ "safeSearch", "none" ],
                     [ "screenOrientation", "automatic" ],
                     [ "mediaPlayer", "Media Player" ],
