@@ -13,7 +13,7 @@ function appendVideoFeed() {
 
         videoListModel.loading = false;
     }
-    doc.open("GET", videoFeed + "&start-index=" + startIndex);
+    doc.open("GET", videoFeed + "&start-index=" + startIndex.toString());
     if ((videoFeed == _FAVOURITES_FEED) || (videoFeed == _UPLOADS_FEED) || (videoFeed == _NEW_SUB_VIDEOS_FEED)) {
         doc.setRequestHeader("Authorization", "GoogleLogin auth=" + YouTube.accessToken);
     }
