@@ -12,6 +12,9 @@
 
 YouTube::YouTube(QObject *parent) :
     QObject(parent), developerKey("AI39si6x9O1gQ1Z_BJqo9j2n_SdVsHu1pk2uqvoI3tVq8d6alyc1og785IPCkbVY3Q5MFuyt-IFYerMYun0MnLdQX5mo2BueSw"), playbackFormat(18) {
+    pbMap["720p"] = 22;
+    pbMap["480p"] = 35;
+    pbMap["360p"] = 34;
     pbMap["hq"] = 18;
     pbMap["mobile"] = 5;
 }
@@ -46,10 +49,6 @@ void YouTube::checkLogin() {
     QList<QByteArray> sp = response.split('=');
     QByteArray token = sp.last().trimmed();
 
-//    if (sp.first() == "Error") {
-//        setCurrentUser("");
-//        emit alert(sp.first() + ": " + sp.at(1).split('\n').first());
-//    }
     if ((token.isEmpty()) || (token == "BadAuthentication")) {
         setCurrentUser("");
         emit alert(tr("Authentication failed"));
@@ -57,53 +56,10 @@ void YouTube::checkLogin() {
     else {
         setAccessToken(token);
         emit alert(tr("You are signed in to YouTube as '") + getCurrentUser() + "'");
-        siteLogin();
     }
     reply->deleteLater();
 }
 
-void YouTube::siteLogin() {
-    QNetworkRequest request(QUrl("https://www.youtube.com/signup?next=/&gl=US&hl=en"));
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.12) Gecko/20101028 Firefox/3.6.12");
-    request.setRawHeader("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
-    request.setRawHeader("Accept-Language", "en-us,en;q=0.5");
-    request.setRawHeader("Accept-Charset", "ISO-8859-1,utf-8;q=0.7,*;q=0.7");
-    QByteArray loginData("current_form=loginForm&next=/&action_login=Log In&username=mythmarx&password=stuhowarth1977");
-    QNetworkReply* reply = nam->post(request, loginData.toPercentEncoding());
-    connect(reply, SIGNAL(finished()), this, SLOT(checkSiteLogin()));
-}
-
-void YouTube::checkSiteLogin() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
-    if (!reply) {
-        qDebug() << "Error - no reply";
-        return;
-    }
-
-    QByteArray response = reply->readAll();
-//    qDebug() << response;
-    QNetworkRequest request(QUrl("http://www.youtube.com/verify_age?next_url=/&gl=US&hl=en"));
-    request.setRawHeader("User-Agent", "Mozilla/5.0 (X11; U; Linux x86_64; en-US; rv:1.9.2.12) Gecko/20101028 Firefox/3.6.12");
-    request.setRawHeader("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8");
-    request.setRawHeader("Accept-Language", "en-us,en;q=0.5");
-    request.setRawHeader("Accept-Charset", "ISO-8859-1,utf-8;q=0.7,*;q=0.7");
-    QByteArray ageData("next_url=/&action_confirm=Confirm");
-    reply = nam->post(request, ageData.toPercentEncoding());
-    connect(reply, SIGNAL(finished()), this, SLOT(checkAgeVerification()));
-}
-
-void YouTube::checkAgeVerification() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
-    if (!reply) {
-        qDebug() << "Error - no reply";
-        return;
-    }
-
-//    QByteArray response = reply->readAll();
-//    qDebug() << response;
-    reply->deleteLater();
-}
-
 void YouTube::setCurrentUser(const QString &user) {
     currentUser = user;
     emit currentUserChanged();
@@ -125,7 +81,7 @@ void YouTube::uploadVideo(const QString &filename, const QString &title, const Q
                    "xmlns:yt=\"http://gdata.youtube.com/schemas/2007\">\n" \
                    "<media:group>\n" \
                    "<media:title>" + title.toAscii() + "</media:title>\n" \
-                   "<media:description>\n" + description.toAscii() + "\n\n" + "Uploaded via cuteTube on the Nokia N900\n</media:description>\n" \
+                   "<media:description>\n" + description.toAscii() + "\n\n" + "Uploaded via cuteTube on Symbian^3\n</media:description>\n" \
                    "<media:category scheme=\"http://gdata.youtube.com/schemas/2007/categories.cat\">\n" + category.toAscii() + "\n</media:category>\n" \
                    "<media:keywords>" + tags.toAscii() + "</media:keywords>\n" \
                    "</media:group>\n" \
@@ -393,7 +349,8 @@ void YouTube::replyToComment(const QString &videoId, const QString &commentId, c
     postRequest(url, xml);
 }
 
-void YouTube::getVideoUrl(const QString &playerUrl) {
+void YouTube::getVideoUrl(const QString &videoId) {
+    QString playerUrl = "http://www.youtube.com/get_video_info?&video_id=" + videoId.toAscii() + "&ps=default&eurl=&gl=US&hl=en";
     QNetworkAccessManager *manager = new QNetworkAccessManager(this);
     QNetworkRequest request;
     request.setUrl(QUrl(playerUrl));
@@ -410,18 +367,21 @@ void YouTube::parseVideoPage(QNetworkReply *reply) {
     QNetworkAccessManager *manager = qobject_cast<QNetworkAccessManager*>(sender());
 
     QMap<int, QByteArray> formats;
-    QByteArray response = reply->readAll();
+    QByteArray response = QByteArray::fromPercentEncoding(reply->readAll());
 //    qDebug() << response;
-    response = response.simplified().replace(QByteArray(" "), QByteArray(""));
-    int pos = response.indexOf("\",\"fmt_url_map\":\"") + 17;
-    int pos2 = response.indexOf('\"', pos);
+    int pos = response.indexOf("fmt_url_map=") + 12;
+    int pos2 = response.indexOf("&allow_ratings", pos);
+    int pos3 = response.indexOf("&leanback", pos);
+    if ((pos3 > 0) && (pos3 < pos2)) {
+        pos2 = pos3;
+    }
     response = response.mid(pos, pos2 - pos);
     QList<QByteArray> parts = response.split('|');
     int key = parts.first().toInt();
     for (int i = 1; i < parts.length(); i++) {
         QByteArray part = parts[i];
         QList<QByteArray> keyAndValue = part.split(',');
-        QByteArray url = keyAndValue.first().replace(QByteArray("\\/"), QByteArray("/")).replace(QByteArray("\\u0026"), QByteArray("&"));
+        QByteArray url = keyAndValue.first();
         formats[key] = url;
         key = keyAndValue.last().toInt();
     }
