@@ -39,15 +39,12 @@ public slots:
     void addComment(const QString &videoId, const QString &comment);
     void replyToComment(const QString &videoId, const QString &commentId, const QString &comment);
     void setPlaybackQuality(const QString &quality);
-    void getVideoUrl(const QString &playerUrl);
+    void getVideoUrl(const QString &videoId);
     void uploadVideo(const QString &filename, const QString &title, const QString &description, const QString &tags, const QString &category, const bool &isPrivate);
     void abortVideoUpload();
 
 private slots:
     void checkLogin();
-    void siteLogin();
-    void checkSiteLogin();
-    void checkAgeVerification();
     void setCurrentUser(const QString &user);
     void setAccessToken(const QByteArray &token);
     void setUploadUrl();
